pub enum DecoderError {
HeaderIndexOutOfBounds,
IntegerDecodingError(IntegerDecodingError),
StringDecodingError(StringDecodingError),
InvalidMaxDynamicSize,
SizeUpdateAtEnd,
}Expand description
Represents all errors that can be encountered while performing the decoding of an HPACK header set.
Variants
HeaderIndexOutOfBounds
IntegerDecodingError(IntegerDecodingError)
StringDecodingError(StringDecodingError)
InvalidMaxDynamicSize
The size of the dynamic table can never be allowed to exceed the max size mandated to the decoder by the protocol. (by performing changes made by SizeUpdate blocks).
SizeUpdateAtEnd
A header block cannot end with a dynamic table size update, it must be treating as a decoding error.